@@ -1,6 +1,6 @@
 from itsicli.content_packs.files import ContentPackConfig, ContentPackManifest, InvalidWorkspace
 from itsicli.content_packs.workspace import root_path
-
+from itsicli.setup_logging import logger
 
 def request_input(prompt, validate=lambda x: x):
     while True:
@@ -16,9 +16,6 @@ class BaseCommand(object):
     def add_to_parser(cls, parser):
         pass
 
-    def setup_logger(self):
-        pass
-
     def run(self, args):
         raise NotImplementedError
 
@@ -31,21 +28,22 @@ class WorkspaceCommand(BaseCommand):
         self.home_path = root_path()
 
         if not self.home_path:
-            raise InvalidWorkspace(
-                '\n'.join([
+            msg = '\n'.join([
                     "\nUnable to determine a valid workspace from your current path.",
                     "\nMake sure you're in the correct directory, or try running the 'init' command first."
                 ])
-            )
+            logger.error(msg)
+            raise InvalidWorkspace(msg)
 
         self.config = ContentPackConfig(self.home_path)
 
         if not self.config.id:
-            raise InvalidWorkspace(
-                '\n'.join([
+            msg = '\n'.join([
                     '\nUnable to determine the current content pack id.'
                     "\nMake sure you're in the correct directory, or try running the 'init' command first."
                 ])
-            )
+            logger.error(msg)
+            raise InvalidWorkspace(msg)
+
 
         self.manifest = ContentPackManifest(self.home_path)
