@@ -1,10 +1,10 @@
 # ${copyright}
 
-import logging
 import os
 
 from pathlib import Path
 
+from itsicli.setup_logging import logger
 from itsicli.content_packs.backup.workspace_import import BackupImporter
 from itsicli.content_packs.commands.base import WorkspaceCommand
 
@@ -27,11 +27,11 @@ class ImportBackupCommand(WorkspaceCommand):
     def run(self, args):
         backup_file = getattr(args, self.Args.BACKUP_FILE_PATH)
 
-        logging.info("Backup file path is set to '{}'".format(backup_file))
+        logger.info("Backup file path is set to '{}'".format(backup_file))
 
         self.import_from_backup_file(self.config.id, backup_file)
 
-        logging.info('Done.')
+        logger.info('Done.')
 
     def import_from_backup_file(self, content_pack_id, backup_file):
         if not backup_file:
