@@ -1,6 +1,6 @@
 # ${copyright}
 
-import logging
+from itsicli.setup_logging import logger
 from pathlib import Path
 
 
@@ -17,15 +17,15 @@ class Scaffolder(object):
     def create_file(self, filename):
         path = self.root.joinpath(filename)
         if path.exists():
-            logging.info('{} already exists.'.format(path))
+            logger.info('{} already exists.'.format(path))
             return path
 
         template_path = RESOURCES.joinpath(filename)
         if template_path.is_dir():
-            logging.info('Creating directory at {} ...'.format(path))
+            logger.info('Creating directory at {} ...'.format(path))
             path.mkdir()
         else:
-            logging.info('Creating file at {} ...'.format(path))
+            logger.info('Creating file at {} ...'.format(path))
             contents = template_path.read_bytes()
             path.parent.mkdir(parents=True, exist_ok=True)
             path.write_bytes(contents)
